referrerpolicy=no-referrer-when-downgrade

Deposits

Type Alias Deposits 

pub type Deposits<T: Config> = StorageDoubleMap<_GeneratedPrefixForStorageDeposits<T>, Twox64Concat, T::AccountId, Twox64Concat, BlockNumberFor<T>, <<T as Config>::Currency as Inspect<<T as Config>::AccountId>>::Balance, OptionQuery>;
Holds the reserve that was taken from an account at a specific block number.

This helps governance to have an overview of outstanding deposits that should be returned or slashed.

Storage type is [StorageDoubleMap] with key1 type T :: AccountId, key2 type BlockNumberFor < T > and value type BalanceOf < T >.

Aliased Type

pub struct Deposits<T: Config>(/* private fields */);